summaryrefslogtreecommitdiffstats
path: root/kmail/folderstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderstorage.h')
-rw-r--r--kmail/folderstorage.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/kmail/folderstorage.h b/kmail/folderstorage.h
index 9b71f28af..8c4c648f1 100644
--- a/kmail/folderstorage.h
+++ b/kmail/folderstorage.h
@@ -63,7 +63,7 @@ namespace KMail {
}
using KMail::AttachmentStrategy;
-typedef QValueList<Q_UINT32> SerNumList;
+typedef TQValueList<Q_UINT32> SerNumList;
/**
* @short The FolderStorage class is the bass class for the storage related
@@ -95,12 +95,12 @@ public:
virtual KMFolderType folderType() const { return KMFolderTypeUnknown; }
/** Returns the filename of the folder (reimplemented in KMFolderImap) */
- virtual QString fileName() const;
+ virtual TQString fileName() const;
/** Returns full path to folder file */
- QString location() const;
+ TQString location() const;
/** Returns full path to index file */
- virtual QString indexLocation() const = 0;
+ virtual TQString indexLocation() const = 0;
/** Returns, if the folder can't contain mails, but only subfolder */
virtual bool noContent() const { return mNoContent; }
@@ -159,9 +159,9 @@ public:
* for each derived KMFolder).
*/
virtual FolderJob* createJob( KMMessage *msg, FolderJob::JobType jt = FolderJob::tGetMessage,
- KMFolder *folder = 0, QString partSpecifier = QString::null,
+ KMFolder *folder = 0, TQString partSpecifier = TQString::null,
const AttachmentStrategy *as = 0 ) const;
- virtual FolderJob* createJob( QPtrList<KMMessage>& msgList, const QString& sets,
+ virtual FolderJob* createJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
FolderJob::JobType jt = FolderJob::tGetMessage,
KMFolder *folder = 0 ) const;
@@ -181,7 +181,7 @@ public:
/** Detach message from this folder. Usable to call addMsg() afterwards.
Loads the message if it is not loaded up to now. */
virtual KMMessage* take(int idx);
- virtual void take(QPtrList<KMMessage> msgList);
+ virtual void take(TQPtrList<KMMessage> msgList);
/** Add the given message to the folder. Usually the message
is added at the end of the folder. Returns zero on success and
@@ -202,7 +202,7 @@ public:
* Adds the given messages to the folder. Behaviour is identical
* to addMsg(msg)
*/
- virtual int addMsg( QPtrList<KMMessage>&, QValueList<int>& index_return );
+ virtual int addMsg( TQPtrList<KMMessage>&, TQValueList<int>& index_return );
/** Called by derived classes implementation of addMsg.
Emits msgAdded signals */
@@ -214,8 +214,8 @@ public:
/** Remove (first occurrence of) given message from the folder. */
virtual void removeMsg(int i, bool imapQuiet = false);
- virtual void removeMsg(const QPtrList<KMMsgBase>& msgList, bool imapQuiet = false);
- virtual void removeMsg(const QPtrList<KMMessage>& msgList, bool imapQuiet = false);
+ virtual void removeMsg(const TQPtrList<KMMsgBase>& msgList, bool imapQuiet = false);
+ virtual void removeMsg(const TQPtrList<KMMessage>& msgList, bool imapQuiet = false);
/** Delete messages in the folder that are older than days. Return the
* number of deleted messages. */
@@ -226,7 +226,7 @@ public:
code on failure. The index of the new message is stored in index_return
if given. */
virtual int moveMsg(KMMessage* msg, int* index_return = 0);
- virtual int moveMsg(QPtrList<KMMessage>, int* index_return = 0);
+ virtual int moveMsg(TQPtrList<KMMessage>, int* index_return = 0);
/** Returns the index of the given message or -1 if not found. */
virtual int find(const KMMsgBase* msg) const = 0;
@@ -308,7 +308,7 @@ public:
/** Physically rename the folder. Returns zero on success and an errno
on failure. */
- virtual int rename(const QString& newName, KMFolderDir *aParent = 0);
+ virtual int rename(const TQString& newName, KMFolderDir *aParent = 0);
/** Returns TRUE if a table of contents file is automatically created. */
bool autoCreateIndex() const { return mAutoCreateIndex; }
@@ -343,7 +343,7 @@ public:
virtual bool isReadOnly() const = 0;
/** Returns the label of the folder for visualization. */
- QString label() const;
+ TQString label() const;
/** A cludge to help make sure the count of unread messges is kept in sync */
virtual void correctUnreadMsgsCount();
@@ -363,13 +363,13 @@ public:
/** Set the status of the message at index @p idx to @p status. */
virtual void setStatus(int idx, KMMsgStatus status, bool toggle=false);
- /** Set the status of the message(s) in the QValueList @p ids to @p status. */
- virtual void setStatus(QValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ /** Set the status of the message(s) in the TQValueList @p ids to @p status. */
+ virtual void setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
void removeJobs();
/** Escape a leading dot */
- static QString dotEscape(const QString&);
+ static TQString dotEscape(const TQString&);
/** Read the config file */
virtual void readConfig();
@@ -442,7 +442,7 @@ signals:
/** Emitted when the location on disk of the folder changes. This
* is used by all code which uses the locatio on disk of the folder storage
* ( or the cache storage ) as an identifier for the folder. */
- void locationChanged( const QString &, const QString & );
+ void locationChanged( const TQString &, const TQString & );
/** Emitted when the contents type (calendar, mail, tasks, ..) of the
* folderstorage changes. */
@@ -455,7 +455,7 @@ signals:
void msgRemoved(KMFolder*, Q_UINT32 sernum);
/** Emitted after a message is removed from the folder. */
- void msgRemoved( int idx, QString msgIdMD5 );
+ void msgRemoved( int idx, TQString msgIdMD5 );
void msgRemoved( KMFolder* );
/** Emitted when a message is added from the folder. */
@@ -469,7 +469,7 @@ signals:
void msgHeaderChanged(KMFolder*, int);
/** Emmited to display a message somewhere in a status line. */
- void statusMsg(const QString&);
+ void statusMsg(const TQString&);
/** Emitted when number of unread messages has changed. */
void numUnreadMsgsChanged( KMFolder* );
@@ -482,7 +482,7 @@ signals:
* The matching serial numbers are included
* If @p complete is true the search is done
*/
- void searchResult( KMFolder*, QValueList<Q_UINT32>,
+ void searchResult( KMFolder*, TQValueList<Q_UINT32>,
const KMSearchPattern*, bool complete );
/**
@@ -511,7 +511,7 @@ public slots:
void slotEmitChangedTimer();
protected slots:
- virtual void removeJob( QObject* );
+ virtual void removeJob( TQObject* );
/** Process the next search batch */
void slotProcessNextSearchBatch();
@@ -524,8 +524,8 @@ protected:
* @see createJob
*/
virtual FolderJob* doCreateJob( KMMessage *msg, FolderJob::JobType jt, KMFolder *folder,
- QString partSpecifier, const AttachmentStrategy *as ) const = 0;
- virtual FolderJob* doCreateJob( QPtrList<KMMessage>& msgList, const QString& sets,
+ TQString partSpecifier, const AttachmentStrategy *as ) const = 0;
+ virtual FolderJob* doCreateJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
FolderJob::JobType jt, KMFolder *folder ) const = 0;
/** Tell the folder that a header field that is usually used for
@@ -624,9 +624,9 @@ friend class KMMsgDict;
/** Points at the reverse dictionary for this folder. */
mutable KMMsgDictREntry *mRDict;
/** List of jobs created by this folder. */
- mutable QPtrList<FolderJob> mJobList;
+ mutable TQPtrList<FolderJob> mJobList;
- QTimer *mDirtyTimer;
+ TQTimer *mDirtyTimer;
enum { mDirtyTimerInterval = 600000 }; // 10 minutes
ChildrenState mHasChildren;
@@ -636,7 +636,7 @@ friend class KMMsgDict;
KMFolder* mFolder;
- QTimer * mEmitChangedTimer;
+ TQTimer * mEmitChangedTimer;
int mCurrentSearchedMsg;
const KMSearchPattern* mSearchPattern;